# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtconnectivity-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtbluetooth   %mklibname qt%{qtmajor}bluetooth %{qtmajor}
%define libqtbluetooth_d %mklibname qt%{qtmajor}bluetooth -d

%define libqtnfc         %mklibname qt%{qtmajor}nfc %{qtmajor}
%define libqtnfc_d       %mklibname qt%{qtmajor}nfc -d
%define libqtnfc_p_d     %mklibname qt%{qtmajor}nfc-private -d

Name:           qtconnectivity5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Connectivity component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
Patch10:        CVE-2025-23050-qtconnectivity-5.15.diff
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtconnectivity
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-sdpscanner-fix-format-strings-for-u-int64_t.patch

BuildRequires:  qtbase5-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(bluez)
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora
Patch0:        qt5-qtconnectivity-gcc11.patch

%description
Qt%{qtmajor} Connectivity component.

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtConnectivity%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtConnectivity%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtbluetooth.qch
%{_qt5_docdir}/qtbluetooth/
%{_qt5_docdir}/qtnfc.qch
%{_qt5_docdir}/qtnfc/
%endif

#------------------------------------------------------------------------------

%package -n qtbluetooth5
Summary:        Qt%{qtmajor} Bluetooth Component Library
Group:          System/Libraries
Requires:       %{libqtbluetooth} = %{version}
Provides:       qt5bluetooth = %{version}
Provides:       qt%{qtmajor}-qtbluetooth = %{version}

%description -n qtbluetooth5
Qt%{qtmajor} Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n qtbluetooth5
%{_qt5_bindir}/sdpscanner
%{_qt5_qml}/QtBluetooth

#------------------------------------------------------------------------------

%package -n %{libqtbluetooth}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Requires:       bluez

%description -n %{libqtbluetooth}
Qt%{qtmajor} Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n %{libqtbluetooth}
%{_qt5_libdir}/libQt5Bluetooth.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtbluetooth_d}
Summary:        Devel files needed to build apps based on QtBluetooth
Group:          Development/KDE and Qt
Requires:       %{libqtbluetooth} = %{version}
Provides:       libqtbluetooth5-devel = %{version}
Provides:       libqt5bluetooth-devel = %{version}
Provides:       qtbluetooth5-devel = %{version}
Provides:       qt5bluetooth-devel = %{version}

Provides:       libqtbluetooth5-private-devel = %{version}
Provides:       libqt5bluetooth-private-devel = %{version}
Provides:       qtbluetooth5-private-devel = %{version}
Provides:       qt5bluetooth-private-devel = %{version}

%description -n %{libqtbluetooth_d}
Devel files needed to build apps based on Qt Bluetooth.

%files -n %{libqtbluetooth_d}
%{_qt5_libdir}/libQt5Bluetooth.prl
%{_qt5_libdir}/libQt5Bluetooth.so
%{_qt5_libdir}/pkgconfig/Qt5Bluetooth.pc
%{_qt5_libdir}/cmake/Qt5Bluetooth
%{_qt5_examplesdir}/bluetooth
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_bluetooth.pri
%{_qt5_includedir}/QtBluetooth/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_bluetooth_private.pri

#------------------------------------------------------------------------------

%package -n qtnfc5
Summary:        Qt%{qtmajor} Nfc Component Library
Group:          System/Libraries
Requires:       %{libqtnfc} = %{version}
Provides:       qt5nfc = %{version}
Provides:       qt%{qtmajor}-qtnfc = %{version}

%description -n qtnfc5
Qt%{qtmajor} Component Library.

The Qt Nfc Enables connectivity between NFC enabled devices.

%files -n qtnfc5
%{_qt5_qml}/QtNfc

#------------------------------------------------------------------------------

%package -n %{libqtnfc}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries

%description -n %{libqtnfc}
Qt%{qtmajor} Component Library.

The Qt Nfc Enables connectivity between NFC enabled devices.

%files -n %{libqtnfc}
%{_qt5_libdir}/libQt5Nfc.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtnfc_d}
Summary:        Devel files needed to build apps based on QtNfc
Group:          Development/KDE and Qt
Requires:       %{libqtnfc} = %{version}
Provides:       libqtnfc5-devel = %{version}
Provides:       libqt5nfc-devel = %{version}
Provides:       qtnfc5-devel = %{version}
Provides:       qt5nfc-devel = %{version}

Provides:       libqtnfc5-private-devel = %{version}
Provides:       libqt5nfc-private-devel = %{version}
Provides:       qtnfc5-private-devel = %{version}
Provides:       qt5nfc-private-devel = %{version}

%description -n %{libqtnfc_d}
Devel files needed to build apps based on Qt Nfc.

%files -n %{libqtnfc_d}
%{_qt5_libdir}/libQt5Nfc.prl
%{_qt5_libdir}/libQt5Nfc.so
%{_qt5_libdir}/pkgconfig/Qt5Nfc.pc
%{_qt5_libdir}/cmake/Qt5Nfc/
%{_qt5_examplesdir}/nfc
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_nfc.pri
%{_qt5_includedir}/QtNfc/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_nfc_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtconnectivity-everywhere-src-%{qtversion}

%build
%qmake_qt5
%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif


%changelog
* Sat Feb 08 2025 daviddavid <daviddavid> 5.15.16-2.mga10
+ Revision: 2146105
- backport upstream patch to fix CVE-2025-23050

* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139630
- New version 5.15.16

* Tue Jan 16 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2031688
- New version 5.15.12

* Sat Dec 03 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1915387
- New version 5.15.7

* Sat Sep 10 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886493
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881055
- New version 5.15.5

* Mon Apr 04 2022 umeabot <umeabot> 5.15.2-3.mga9
+ Revision: 1843598
- Mageia 9 Mass Rebuild

* Mon May 03 2021 daviddavid <daviddavid> 5.15.2-2.mga9
+ Revision: 1721052
- add patch to fix build with gcc 11

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652448
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624901
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589813
- New version 5.15.0
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545485
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484389
- New version 5.14.1

* Sun Sep 08 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438479
- New version 5.13.1

* Mon Jul 15 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421490
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418151
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384351
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378529
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362274
- New version 5.12.1

* Sun Dec 09 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1339129
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319018
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300696
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245805
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232104
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216499
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205673
- New version 5.9.4

* Mon Dec 18 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1183176
- New version 5.9.3

* Sun Jul 16 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1123562
- New version 5.9.1
- New version 5.9.1

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-1.mga6
+ Revision: 1064817
- New version 5.6.2
- New version 5.6.2

* Fri Sep 02 2016 daviddavid <daviddavid> 5.6.1-3.mga6
+ Revision: 1049776
- build missing docs part (mga#9812)
- add qtconnectivity5-doc subpackage

* Sun Jul 03 2016 neoclust <neoclust> 5.6.1-2.mga6
+ Revision: 1038369
- Update to version 5.6.1-1
- New version

* Thu Mar 17 2016 neoclust <neoclust> 5.6.0-1.mga6
+ Revision: 992392
- New version
- New version

* Wed Mar 09 2016 neoclust <neoclust> 5.6.0-0.rc.2.mga6
+ Revision: 987812
- Rebuild Qt5 Stack to fix plasma crashes

* Sun Feb 28 2016 neoclust <neoclust> 5.6.0-0.rc.1.mga6
+ Revision: 980605
+ rebuild (emptylog)

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.4.mga6
+ Revision: 915979
- Rebuild against new cmake to have cmake() provides

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.3.mga6
+ Revision: 915784
- Rebuild against new cmake to have cmake() provides

* Sun Dec 20 2015 neoclust <neoclust> 5.6.0-0.beta.2.mga6
+ Revision: 912725
- Remove private devel packages

* Fri Dec 18 2015 neoclust <neoclust> 5.6.0-0.beta.1.mga6
+ Revision: 911657
- New version 5.6.0 beta

* Tue Nov 10 2015 neoclust <neoclust> 5.5.1-2.mga6
+ Revision: 900355
- Rebuild against fixed qtbase5

* Fri Oct 23 2015 neoclust <neoclust> 5.5.1-1.mga6
+ Revision: 894489
- New version

* Sun Jul 12 2015 filipesaraiva <filipesaraiva> 5.5.0-1.mga6
+ Revision: 853375
- Update to Qt 5.5.0 version;
- Fix URL to new address qt.io;

* Tue Jun 23 2015 neoclust <neoclust> 5.5.0-0.rc.1.mga6
+ Revision: 840000
- New version 5.5 rc

* Fri Dec 12 2014 neoclust <neoclust> 5.4.0-1.mga5
+ Revision: 802847
- New version 5.4.0

* Sun Dec 07 2014 neoclust <neoclust> 5.3.2-1.mga5
+ Revision: 801796
- New version 5.3.2

* Wed Oct 15 2014 umeabot <umeabot> 5.3.1-3.mga5
+ Revision: 746895
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.3.1-2.mga5
+ Revision: 688537
- Mageia 5 Mass Rebuild

* Thu Jun 26 2014 fwang <fwang> 5.3.1-1.mga5
+ Revision: 639771
- 5.3.1

* Tue May 20 2014 fwang <fwang> 5.3.0-1.mga5
+ Revision: 624079
- 5.3.0 final

* Fri May 09 2014 fwang <fwang> 5.3.0-0.rc.1.mga5
+ Revision: 621405
- 5.3.0 rc

* Sat Apr 05 2014 fwang <fwang> 5.3.0-0.beta.1.mga5
+ Revision: 611990
- 5.3.0beta

* Mon Mar 03 2014 neoclust <neoclust> 5.3.0-0.alpha.1.mga5
+ Revision: 598925
- New version

* Mon Feb 17 2014 fwang <fwang> 5.2.1-3.mga5
+ Revision: 593321
- fix libpkgname

* Mon Feb 17 2014 fwang <fwang> 5.2.1-2.mga5
+ Revision: 593221
- requires bluez dbus interface to work

* Mon Feb 17 2014 fwang <fwang> 5.2.1-1.mga5
+ Revision: 593216
- update br
- imported package qtconnectivity5

